import os
import sys

try:
    from .__system__.index import index
except ModuleNotFoundError as e:
    print("\nModules should be imported into the project!")
    print(f"Error: {e}")
    sys.exit()

_app_ = os.path.dirname(__file__)
_obj_ = index(_app_, os.getcwd(), [])
for item in dir(_obj_):
    if item[:1] == "_":
        continue
    globals()[item] = getattr(_obj_, item)



from setuptools import setup, find_packages

setup(
    name="aisi",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[
        "clight",
        
    ],
    entry_points={
        "console_scripts": [
            "aisi=aisi.main:main",  # Entry point of the app
        ],
    },
    package_data={
        "aisi": [
            "main.py",
            "__init__.py",
            "__system__/imports.py",
            "__system__/index.py",
            "__system__/modules/jobs.py",
            "__system__/sources/clight.json"
        ],
    },
    include_package_data=True,
    author="Irakli Gzirishvili",
    author_email="gziraklirex@gmail.com",
    description="Pending",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="",
    classifiers=[
        "Programming Language :: Python :: 3",
        
        "Operating System :: OS Independent",
    ],
)



from .imports import *


class index:
    ####################################################################################// Load
    def __init__(self, app="", cwd="", args=[]):
        self.app, self.cwd, self.args = app, cwd, args
        # ...
        pass

    ####################################################################################// Main
    def demo(self, param=""):  # (param) - Test demo method with param
        if not param:
            return "Invalid param!"

        cli.hint(param)
        # cli.info(param)
        # cli.done(param)
        # cli.error(param)

        # text = cli.input("Enter Text", True)
        # option = cli.selection("Select Option", ["Option 1", "Option 2"])
        # action = cli.confirmation("Would you like to confirm this action?")

        return self.__helper()

    ####################################################################################// Helpers
    def __helper(self):
        return jobs.test()
